#!moo verb eject --on $root_class

# pylint: disable=return-outside-function,undefined-variable

"""
This verb is used to remove something from the contents of an object. The owner of an object, or a wizard, can use this
verb to eject a victim from inside the object. The victim is sent to None, for most objects, or to $player_start if
the victim is a player.
"""



#!moo verb match_object --on $room

# pylint: disable=return-outside-function,undefined-variable

"""
This is the verb used to search the player's locale for an object that has the name or pseudonym name. This verb
handles mapping of me to the player object, here to the player's location as well as the use of #<number> to refer to a
particular object. If none of these cases match, the verb searches the room contents and the players contents (or
possessions) for a match. If a match is found, then the unique object number is returned. If name matches more than one
object, then $ambiguous_match is returned. If no match is found, then $failed_match is returned.

The verb :match_object is the one to use to map names of objects to object numbers, when referring to objects that the
player is able to see in his current location. This includes objects that the player might be carrying, but does not
include objects that are contained in other objects.
"""
